==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/PolymerVillagerProfessionHelper.java <==
package cc.thonly.polymer;

import cc.thonly.reverie_dreams.entity.villager.ModVillagerProfessions;
import eu.pb4.polymer.core.api.entity.PolymerEntityUtils;
import eu.pb4.polymer.core.api.entity.PolymerVillagerProfession;
import eu.pb4.polymer.core.api.utils.PolymerSyncedObject;
import net.minecraft.class_3852;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import xyz.nucleoid.packettweaker.PacketContext;

public class PolymerVillagerProfessionHelper {
    public static void bootstrap() {
        registerOverlay(ModVillagerProfessions.HAWKERS, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17053);
            }
        });
        registerOverlay(ModVillagerProfessions.PRIEST, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17055);
            }
        });
        registerOverlay(ModVillagerProfessions.MONEY_SHOP_CLERK, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17060);
            }
        });
    }

    public static void registerOverlay(class_5321<class_3852> registryKey, PolymerSyncedObject<class_3852> overlay) {
        class_3852 profession = class_7923.field_41195.method_29107(registryKey);
        PolymerEntityUtils.registerProfession(profession, overlay);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/polymer/PolymerVillagerProfessionHelper.java <==
package cc.thonly.polymer;

import cc.thonly.reverie_dreams.entity.villager.RDVillagerProfessions;
import eu.pb4.polymer.core.api.entity.PolymerEntityUtils;
import eu.pb4.polymer.core.api.entity.PolymerVillagerProfession;
import eu.pb4.polymer.core.api.utils.PolymerSyncedObject;
import net.minecraft.class_3852;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import xyz.nucleoid.packettweaker.PacketContext;

public class PolymerVillagerProfessionHelper {
    public static void bootstrap() {
        registerOverlay(RDVillagerProfessions.HAWKERS, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17053);
            }
        });
        registerOverlay(RDVillagerProfessions.PRIEST, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17055);
            }
        });
        registerOverlay(RDVillagerProfessions.MONEY_SHOP_CLERK, new PolymerVillagerProfession() {
            @Override
            public class_3852 getPolymerReplacement(class_3852 object, PacketContext context) {
                return class_7923.field_41195.method_29107(class_3852.field_17060);
            }
        });
    }

    public static void registerOverlay(class_5321<class_3852> registryKey, PolymerSyncedObject<class_3852> overlay) {
        class_3852 profession = class_7923.field_41195.method_29107(registryKey);
        PolymerEntityUtils.registerProfession(profession, overlay);
    }
}
